==> download.php?FileName=TerraView-5.1.3-src.tar.gz: TerraView-5.1.3-src/share/terralib/translations/terralib_mod_qt_plugins_datasource_ogr_pt_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>OGRConnectorDialogForm</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="14"/>
        <source>OGR Connector</source>
        <translation>Conector OGR</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="39"/>
        <source>OGR - Simple Features</source>
        <translation>OGR - Feições Simples</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="51"/>
        <source>Feature access information</source>
        <translation>Informações de acesso da feição</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="74"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="89"/>
        <source>File</source>
        <translation>Arquivo</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="99"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="106"/>
        <source>Directory</source>
        <translation>Diretório</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="118"/>
        <source>Data Source Title</source>
        <translation>Título da Fonte de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="128"/>
        <source>Data Source Description</source>
        <translation>Descrição da Fonte de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="147"/>
        <source>A more detailed description about the data source</source>
        <translation>Uma descrição mais detalhada sobre a fonte de dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="163"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="185"/>
        <source>&amp;Test</source>
        <translation>&amp;Teste</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="192"/>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="199"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="94"/>
        <source>ESRI Shapefile (*.shp *.SHP)</source>
        <translation>ESRI Shapefile (*.shp *.SHP)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="96"/>
        <source>MapInfo File (*.mif *.MIF)</source>
        <translation>Arquivo MapInfo (*.mif *.MIF)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="98"/>
        <source>DGN File (*.dgn *.DGN)</source>
        <translation>Arquivo DGN (*.dgn *.DGN)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="102"/>
        <source>GML File (*.gml *.GML)</source>
        <translation>Arquivo GML (*.gml *.GML)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="104"/>
        <source>KML File (*.kml *.KML)</source>
        <translation>Arquivo KML (*.kml *.KML)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="106"/>
        <source>GeoJSON File (*.geojson *.GEOJSON)</source>
        <translation>Arquivo GeoJSON (*.geojson *.GEOJSON)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="108"/>
        <source>DXF File (*.dxf *.DXF)</source>
        <translation>Arquivo DXF (*.dxf *.DXF)</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::ogr::OGRConnector</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnector.cpp" line="76"/>
        <source>TerraLib Qt Components</source>
        <translation>Componentes TerraLib Qt</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnector.cpp" line="77"/>
        <source>Not implemented yet!
We will provide it soon!</source>
        <translation>Ainda não implementado!
Iremos fornecer em breve!</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::ogr::OGRConnectorDialog</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="156"/>
        <source>Do you want create spatial index to the selected ESRI ShapeFile?</source>
        <translation>Você deseja criar índice espacial para o arquivo ShapeFile ESRI selecionado ?</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="177"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="184"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="215"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="219"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="225"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="231"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="268"/>
        <source>TerraLib Qt Components</source>
        <translation>Componentes TerraLib Qt</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="185"/>
        <source>Unknown error while opening feature via OGR!</source>
        <translation>Erro desconhecido durante abertura de feição via OGR !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="216"/>
        <source>Directory does not contain datasets!</source>
        <translation>Diretório não contém conjuntos de dados !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="220"/>
        <source>Data source is ok!</source>
        <translation>Fonte de dados está ok !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="232"/>
        <source>Unknown error while testing OGR data source!</source>
        <translation>Erro desconhecido durante teste de fonte de dados OGR !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="240"/>
        <source>Open Vector File</source>
        <translation>Abrir Arquivo Vetorial</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="240"/>
        <source>Esri Shapefile (*.shp *.SHP);; Mapinfo File (*.mif *.MIF);; GeoJSON (*.geojson *.GeoJSON);; GML (*.gml *.GML);; KML (*.kml *.KML);; All Files (*.*)</source>
        <translation>Esri Shapefile (*.shp *.SHP);; Arquivo Mapinfo (*.mif *.MIF);; GeoJSON (*.geojson *.GeoJSON);; GML (*.gml *.GML);; KML (*.kml *.KML);; Todos Arquivos (*.*)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="256"/>
        <source>Select a directory with shape files</source>
        <translation>Selecione um diretório com arquivos shapefile</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="269"/>
        <source>Sorry, network files are not implemented yet!
We will provide it soon!</source>
        <translation>Desculpe, arquivos de rede não estão implementados ainda!
Iremos fornecer em breve!</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::ogr::Plugin</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="164"/>
        <source>Vector File...</source>
        <translation>Arquivo Vetorial...</translation>
    </message>
    <message>
        <source>Vector File</source>
        <translation type="vanished">Arquivo Vetorial</translation>
    </message>
    <message>
        <source>Error: there is no opened project!</source>
        <translation type="vanished">Erro: não há nenhum projeto aberto !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="205"/>
        <source>Open Vector File</source>
        <translation>Abrir Arquivo Vetorial</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="205"/>
        <source>Esri Shapefile (*.shp *.SHP);; Mapinfo File (*.mif *.MIF);; GeoJSON (*.geojson *.GeoJSON);; GML (*.gml *.GML);; KML (*.kml *.KML);; All Files (*.*)</source>
        <translation>Esri Shapefile (*.shp *.SHP);; Arquivo Mapinfo (*.mif *.MIF);; GeoJSON (*.geojson *.GeoJSON);; GML (*.gml *.GML);; KML (*.kml *.KML);; Todos Arquivos (*.*)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="222"/>
        <source>Error occurred trying to create layer(s):

</source>
        <translation>Ocorreu erro ao tentar criar camada(s):

</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="290"/>
        <source>Add Layer</source>
        <translation>Adicionar Camada</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="296"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="314"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="320"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="327"/>
        <source>Spatial Index</source>
        <translation>Índice Espacial</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="296"/>
        <source>Do you want create spatial index to the selected ESRI ShapeFiles?</source>
        <translation>Você deseja criar índice espacial para os arquivos ShapeFiles ESRI selecionados ?</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="351"/>
        <source>Layer %1 has SRID %2 that is not recognized by TerraLib. Setting it to unknown.</source>
        <translation>Camada %1 tem SRID %2 que não é reconhecido pela Terralib. Defini-lo como desconhecido.</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="356"/>
        <source>Layer SRS check</source>
        <translation>SRS da Camada verificada</translation>
    </message>
</context>
</TS>

==> download.php?FileName=TerraView-5.2.3-src.tar.gz: TerraView-5.2.3-src/share/terralib/translations/terralib_mod_qt_plugins_datasource_ogr_pt_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>OGRConnectorDialogForm</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="14"/>
        <source>OGR Connector</source>
        <translation>Conector OGR</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="39"/>
        <source>OGR - Simple Features</source>
        <translation>OGR - Feições Simples</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="51"/>
        <source>Feature access information</source>
        <translation>Informações de acesso da feição</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="74"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="89"/>
        <source>File</source>
        <translation>Arquivo</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="99"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="106"/>
        <source>Directory</source>
        <translation>Diretório</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="118"/>
        <source>Data Source Title</source>
        <translation>Título da Fonte de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="128"/>
        <source>Data Source Description</source>
        <translation>Descrição da Fonte de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="147"/>
        <source>A more detailed description about the data source</source>
        <translation>Uma descrição mais detalhada sobre a fonte de dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="163"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="185"/>
        <source>&amp;Test</source>
        <translation>&amp;Teste</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="192"/>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/ui/OGRConnectorDialogForm.ui" line="199"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="64"/>
        <source>ESRI Shapefile (*.shp *.SHP)</source>
        <translation>ESRI Shapefile (*.shp *.SHP)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="66"/>
        <source>MapInfo File (*.mif *.MIF)</source>
        <translation>Arquivo MapInfo (*.mif *.MIF)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="68"/>
        <source>DGN File (*.dgn *.DGN)</source>
        <translation>Arquivo DGN (*.dgn *.DGN)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="72"/>
        <source>GML File (*.gml *.GML)</source>
        <translation>Arquivo GML (*.gml *.GML)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="74"/>
        <source>KML File (*.kml *.KML)</source>
        <translation>Arquivo KML (*.kml *.KML)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="76"/>
        <source>GeoJSON File (*.geojson *.GEOJSON)</source>
        <translation>Arquivo GeoJSON (*.geojson *.GEOJSON)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="78"/>
        <source>DXF File (*.dxf *.DXF)</source>
        <translation>Arquivo DXF (*.dxf *.DXF)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Utils.cpp" line="126"/>
        <source>Error occurred trying to create layer(s):

</source>
        <translation type="unfinished">Ocorreu erro ao tentar criar camada(s):

</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Utils.cpp" line="192"/>
        <source>Add Layer</source>
        <translation type="unfinished">Adicionar Camada</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Utils.cpp" line="198"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Utils.cpp" line="216"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Utils.cpp" line="222"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Utils.cpp" line="229"/>
        <source>Spatial Index</source>
        <translation type="unfinished">Índice Espacial</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Utils.cpp" line="198"/>
        <source>Do you want create spatial index to the selected ESRI ShapeFiles?</source>
        <translation type="unfinished">Você deseja criar índice espacial para os arquivos ShapeFiles ESRI selecionados ?</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Utils.cpp" line="246"/>
        <source>Layer %1 has SRID %2 that is not recognized by TerraLib. Setting it to unknown.</source>
        <translation type="unfinished">Camada %1 tem SRID %2 que não é reconhecido pela Terralib. Defini-lo como desconhecido.</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Utils.cpp" line="251"/>
        <source>Layer SRS check</source>
        <translation type="unfinished">SRS da Camada verificada</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::ogr::OGRConnector</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnector.cpp" line="74"/>
        <source>TerraLib Qt Components</source>
        <translation>Componentes TerraLib Qt</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnector.cpp" line="75"/>
        <source>Not implemented yet!
We will provide it soon!</source>
        <translation>Ainda não implementado!
Iremos fornecer em breve!</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::ogr::OGRConnectorDialog</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="154"/>
        <source>Do you want create spatial index to the selected ESRI ShapeFile?</source>
        <translation>Você deseja criar índice espacial para o arquivo ShapeFile ESRI selecionado ?</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="175"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="182"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="207"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="211"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="217"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="223"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="260"/>
        <source>TerraLib Qt Components</source>
        <translation>Componentes TerraLib Qt</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="183"/>
        <source>Unknown error while opening feature via OGR!</source>
        <translation>Erro desconhecido durante abertura de feição via OGR !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="208"/>
        <source>Directory does not contain datasets!</source>
        <translation>Diretório não contém conjuntos de dados !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="212"/>
        <source>Data source is ok!</source>
        <translation>Fonte de dados está ok !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="224"/>
        <source>Unknown error while testing OGR data source!</source>
        <translation>Erro desconhecido durante teste de fonte de dados OGR !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="232"/>
        <source>Open Vector File</source>
        <translation>Abrir Arquivo Vetorial</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="232"/>
        <source>Esri Shapefile (*.shp *.SHP);; Mapinfo File (*.mif *.MIF);; GeoJSON (*.geojson *.GeoJSON);; GML (*.gml *.GML);; KML (*.kml *.KML);; All Files (*.*)</source>
        <translation>Esri Shapefile (*.shp *.SHP);; Arquivo Mapinfo (*.mif *.MIF);; GeoJSON (*.geojson *.GeoJSON);; GML (*.gml *.GML);; KML (*.kml *.KML);; Todos Arquivos (*.*)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="248"/>
        <source>Select a directory with shape files</source>
        <translation>Selecione um diretório com arquivos shapefile</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/OGRConnectorDialog.cpp" line="261"/>
        <source>Sorry, network files are not implemented yet!
We will provide it soon!</source>
        <translation>Desculpe, arquivos de rede não estão implementados ainda!
Iremos fornecer em breve!</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::ogr::Plugin</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="137"/>
        <source>Vector File...</source>
        <translation>Arquivo Vetorial...</translation>
    </message>
    <message>
        <source>Vector File</source>
        <translation type="vanished">Arquivo Vetorial</translation>
    </message>
    <message>
        <source>Error: there is no opened project!</source>
        <translation type="vanished">Erro: não há nenhum projeto aberto !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="138"/>
        <source>Add new vector file as a layer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="191"/>
        <source>Open Vector File</source>
        <translation>Abrir Arquivo Vetorial</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/ogr/Plugin.cpp" line="191"/>
        <source>Esri Shapefile (*.shp *.SHP);; Mapinfo File (*.mif *.MIF);; GeoJSON (*.geojson *.GeoJSON);; GML (*.gml *.GML);; KML (*.kml *.KML);; All Files (*.*)</source>
        <translation>Esri Shapefile (*.shp *.SHP);; Arquivo Mapinfo (*.mif *.MIF);; GeoJSON (*.geojson *.GeoJSON);; GML (*.gml *.GML);; KML (*.kml *.KML);; Todos Arquivos (*.*)</translation>
    </message>
    <message>
        <source>Error occurred trying to create layer(s):

</source>
        <translation type="vanished">Ocorreu erro ao tentar criar camada(s):

</translation>
    </message>
    <message>
        <source>Add Layer</source>
        <translation type="vanished">Adicionar Camada</translation>
    </message>
    <message>
        <source>Spatial Index</source>
        <translation type="vanished">Índice Espacial</translation>
    </message>
    <message>
        <source>Do you want create spatial index to the selected ESRI ShapeFiles?</source>
        <translation type="vanished">Você deseja criar índice espacial para os arquivos ShapeFiles ESRI selecionados ?</translation>
    </message>
    <message>
        <source>Layer %1 has SRID %2 that is not recognized by TerraLib. Setting it to unknown.</source>
        <translation type="vanished">Camada %1 tem SRID %2 que não é reconhecido pela Terralib. Defini-lo como desconhecido.</translation>
    </message>
    <message>
        <source>Layer SRS check</source>
        <translation type="vanished">SRS da Camada verificada</translation>
    </message>
</context>
</TS>
